@@ -55,35 +55,40 @@ int Bufferinputbitstream::getbyte(void)
   return -1;
 }
 
+#ifndef WORDS_BIGENDIAN
+#define _KEY 0
+#else
+#define _KEY 3
+#endif
+
 int Bufferinputbitstream::getbits(int bits)
 {
-  int *current,c;
+  int c;
 
-  current=(int *)(store);
-  *((int *)(store+1))=0;
+  u.store[1]=u.store[2]=u.store[3-_KEY]=0;
 
   while(bits)
   {
     if(!bitindex)                    // Charge
     {
       if((c=getbyte())==-1)return -1;
-      store[0]=c;
+      u.store[_KEY]=c;
       bitindex=8;
     }
 
     if(bits>=bitindex)
     {
-      (*current)<<=bitindex;
+      u.current<<=bitindex;
       bits-=bitindex;
       bitindex=0;
     }
     else
     {
-      (*current)<<=bits;
+      u.current<<=bits;
       bitindex-=bits;
       bits=0;
     }
   }
 
-  return *((int *)(store+1));
+  return (u.current>>8);
 }
